function zs = GLAS_RGB(im, alpha, hg)
% Geometric locally adaptive deblurring (GLAD) for RGB images
% [Function input] 
% im:       2D input image
% alpha:    structure sensitivity. The range is [0.5 1]
% hg:       global smoothing parameter. The range is [2.5 4]
% [Function output]
% zs:       output image

y = rgb2ycbcr(im);
y_Y = double(y(:,:,1));
y_Cb = double(y(:,:,2));
y_Cr = double(y(:,:,3));

% pilot estimation by second order classic kernel regression
h = 0.5;    % the smoothing parameter
r = 1;      % the upscaling factor
ksize = 5;  % the kernel size
[zc, zx1c, zx2c] = ckr2_regular(y_Y, h, r, ksize);

% GLAD parameters
wsize = 5;  % the size of the local orientation analysis window
lambda = 0.0001;  % the regularization for the elongation parameter
ksize = 11;  % the GLAD kernel size

% Compute steering matrices and local meric Q
[C LQ] = steering_localq(zx1c, zx2c, ones(size(y_Y)), wsize, lambda, alpha);

% GLAD restoration
tau1 = 100;
tau2 = 150;
beta_Y = 1.5; % % sharpness strenth for Y channel: [1, 2].
beta_CbCr = 0.1; % for Cb Cr channels

zs = zeros(size(y));
zs(:,:,1) = glad_sharpen(y_Y, hg, C, LQ, ksize, tau1, tau2, beta_Y);
zs(:,:,2) = glad_sharpen(y_Cb, hg, C, LQ, ksize, tau1, tau2, beta_CbCr);
zs(:,:,3) = glad_sharpen(y_Cr, hg, C, LQ, ksize, tau1, tau2, beta_CbCr);
zs = ycbcr2rgb(uint8(zs));