function zs = GLAS_grayscale(im, alpha, hg)
% Geometric locally adaptive deblurring (GLAD) for grayscale images
% [Function input] 
% im:       2D input image
% alpha:    structure sensitivity. The range is [0.5, 1]
% hg:       global smoothing parameter. The range is [2.5, 4]
% [Function output]
% zs:       output image

y = double(im);

% pilot estimation by second order classic kernel regression
h = 0.5;    % the smoothing parameter
r = 1;      % the upscaling factor
ksize = 5;  % the kernel size
[zc, zx1c, zx2c] = ckr2_regular(y, h, r, ksize);

% GLAD parameters
wsize = 5;  % the size of the local orientation analysis window
lambda = 0.0001;  % the regularization for the elongation parameter
ksize = 11;  % the GLAD kernel size

% Compute steering matrices and local meric Q
[C LQ] = steering_localq(zx1c, zx2c, ones(size(y)), wsize, lambda, alpha);

% GLAD restoration
tau1 = 150;
tau2 = 200;
beta = 1.5; % sharpness strenth: [1, 2].
zs = glad_sharpen(y, hg, C, LQ, ksize, tau1, tau2, beta);